﻿using System;
using System.Linq;
using System.Text;
using MbUnit.Framework;
using System.Collections;

namespace DataDriven.Tests.Combinational
{
    public interface ICount
    {
        int Count(string s);
    }

    public class BadCounter : ICount
    {
        public int Count(string s)
        {
            return 2;
        }
    }

    public class XCounter : ICount
    {
        public int Count(string s)
        {
            int count = 0;
            foreach (char c in s)
                if (c == 'x' || c == 'X')
                    count++;
            return count;
        }
    }

    //[TestFixture]
    public class ICountTests_Orginal
    {
        [Test]
        public void BadCounter_Count_NoX()
        {
            ICount counter = new BadCounter();
            int result = counter.Count("");
            Assert.AreEqual(0, result);
        }

        [Test]
        public void BadCounter_Count_TwoX()
        {
            ICount counter = new BadCounter();
            int result = counter.Count("XX");
            Assert.AreEqual(2, result);
        }

        [Test]
        public void BadCounter_Count_XSpaceYSpaceZ()
        {
            ICount counter = new BadCounter();
            int result = counter.Count("X Y Z");
            Assert.AreEqual(1, result);
        }

        [Test]
        public void XCounter_Count_NoX()
        {
            ICount counter = new XCounter();
            int result = counter.Count("");
            Assert.AreEqual(0, result);
        }

        [Test]
        public void XCounter_Count_TwoX()
        {
            ICount counter = new XCounter();
            int result = counter.Count("XX");
            Assert.AreEqual(2, result);
        }

        [Test]
        public void XCounter_Count_XSpaceYSpaceZ()
        {
            ICount counter = new XCounter();
            int result = counter.Count("X Y Z");
            Assert.AreEqual(1, result);
        }
    }


    [TestFixture]
    public class ICountTests
    {
        [Factory(typeof(ICount))]
        public IEnumerable Counters()
        {
            yield return new BadCounter();
            yield return new XCounter();
        }

        [Factory(typeof(CombinationTestItem))]
        public IEnumerable Strings()
        {
            yield return new CombinationTestItem("", 0);
            yield return new CombinationTestItem("aaa", 0);
            yield return new CombinationTestItem("x", 1);
            yield return new CombinationTestItem("xa", 1);
            yield return new CombinationTestItem("xax", 2);
            yield return new CombinationTestItem("X x", 2);
            yield return new CombinationTestItem("X X", 2);
        }

        public class CombinationTestItem
        {
            public CombinationTestItem(string value, int xcount) { Input = value; ExpectedOutput = xcount; }
            public string Input;
            public int ExpectedOutput;
        }

        [CombinatorialTest]
        public void CountIsExact([UsingFactories("Counters")] ICount counter, 
                                 [UsingFactories("Strings")] CombinationTestItem s)
        {
            Assert.AreEqual(s.ExpectedOutput, counter.Count(s.Input));
        }
    }
}