﻿using System;
using System.Xml;
using System.Xml.Serialization;
using MbUnit.Framework;

namespace DataDriven.Tests
{
    [DataFixture]
    [ResourceXmlDataProvider(typeof(DataFixtureUnitTests), 
                    @"DataDriven.Tests.DataFixture.DataFixtureSample.xml", "DataFixture/Test")]
    public class DataFixtureUnitTests
    {
        [ForEachTest("Data")] //Gotcha - Don't include a slash!! "/Data" causes it not to display in UI
        public void TestAddMethodUsingXML(XmlNode node)
        {
            int a = Convert.ToInt32(node.Attributes["a"].InnerText);
            int b = Convert.ToInt32(node.Attributes["b"].InnerText);
            Assert.AreEqual(Convert.ToInt32(node.Attributes["expected"].InnerText), a + b);

            //if it was an element - node.ChildNodes[5].InnerText
        }

    }

    #region Serialisation

    [XmlRoot("Data")]
    public class Data
    {
        [XmlAttribute("a")]
        public int a;

        [XmlAttribute("b")]
        public int b;

        [XmlAttribute("expected")]
        public int expected;

        public override string ToString()
        {
            return String.Format("{0} + {1} = {2}", a, b, expected);
        }
    }

    [DataFixture]
    [ResourceXmlDataProvider(typeof(DataDrivenUnitTests_Serialised), "DataDriven.Tests.DataFixture.DataFixtureSample.xml",   //'DataDriven.' is my project name.
                "DataFixture/Test")] 
    public class DataDrivenUnitTests_Serialised
    {
        [ForEachTest("Data", DataType = typeof(Data))] //Gotcha - Don't include a slash!! "/Data" causes it not to display in UI
        public void TestAddMethodUsingXML(Data node)
        {
            int actual = node.a + node.b;

            Assert.AreEqual(node.expected, actual, "Node {0} did not equal {1}", node.expected, actual);
        }

    }

    #endregion

}
