﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using MbUnit.Framework;
using System.Xml;
using System.Xml.Serialization;

namespace DataDriven.Tests.DataFixture
{
    [DataFixture]
    [ResourceXmlDataProvider(typeof(DataFixtureUnitTests), @"DataDriven.Tests.DataFixture.Northwind.xml", "Northwind")]
    public class LinqCustomersTests
    {
        [ForEachTest("Customer", DataType = typeof(TestCustomer))] //Gotcha - Don't include a slash!! "/Data" causes it not to display in UI        
        public void GetCustomer_ValuesFromXML_CustomersMatch(TestCustomer node)
        {
            string customerId = node.CustomerID;
            Console.WriteLine("CustomerID being tested: " + customerId);

            LinqCustomerRepository linq = new LinqCustomerRepository();
            Customer c = linq.GetCustomer(customerId);

            //Is the Customer correct?
            Assert.AreEqual(c.CompanyName, node.CompanyName, "CompanyName not correct");
            Assert.AreEqual(c.ContactName, node.ContactName, "ContactName not correct");
            Assert.AreEqual(c.ContactTitle, node.ContactTitle, "ContactTitle not correct");
            Assert.AreEqual(c.Address, node.Address, "Address not correct");
        }
    }

    [XmlRoot("Customer")]
    public class TestCustomer
    {
        [XmlElement("CustomerID")]
        public string CustomerID;

        [XmlElement("CompanyName")]
        public string CompanyName;

        [XmlElement("ContactName")]
        public string ContactName;

        [XmlElement("ContactTitle")]
        public string ContactTitle;

        [XmlElement("Address")]
        public string Address;

        public override string ToString()
        {
            return String.Format(CustomerID);
        }

    }
}
