﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using MbUnit.Framework;

namespace DataDriven.Tests
{
    [TestFixture]
    public class ProblemWithTestingDatabases
    {
        [Test]
        public void GetCustomers_SingleCustomer_PopulatedList()
        {
            Customer c = TestHelper.InsertCustomer();
            LinqCustomerRepository customerRepository = new LinqCustomerRepository();
            List<Customer> customers = customerRepository.GetCustomers();


            Assert.AreEqual(1, customers.Count);
            Assert.AreEqual(c.CustomerID, customers[0].CustomerID);
        }

        [Test]
        public void InsertCustomer_ValidCustomerObject_UpdatesDatabase()
        {
            Customer sample = new Customer();
            sample.CustomerID = "Test";
            sample.CompanyName = "Fake Company";
            sample.ContactName = "Fake Employee";

            NorthwindDataContext db = new NorthwindDataContext();

            db.Customers.InsertOnSubmit(sample);
            db.SubmitChanges();

            Customer c = (from cust in db.Customers
                          where cust.CustomerID == "Test"
                          select cust).Single();

            Assert.AreEqual(sample.ContactName, c.ContactName);
            Assert.AreEqual(sample.CompanyName, c.CompanyName);
        }

        [Test]
        public void UpdateCustomer_ValidCustomerObject_UpdatesDatabase()
        {
            NorthwindDataContext db = new NorthwindDataContext();


            Customer c = (from cust in db.Customers
                          where cust.CustomerID == "Test"
                          select cust).Single();

            c.CompanyName = "Updated Fake Company";

            db.SubmitChanges();

            Customer c2 = (from cust in db.Customers
                          where cust.CustomerID == "Test"
                          select cust).Single();

            Assert.AreEqual(c.CompanyName, c2.CompanyName);
        }

        [Test]
        public void GetCustomerByCompany_ValidCustomerObject_UpdatesDatabase()
        {
            NorthwindDataContext db = new NorthwindDataContext();

            Customer c = (from cust in db.Customers
                          where cust.CompanyName == "Fake Company"
                          select cust).Single();

            Assert.AreEqual("Test", c.CustomerID);
        }
    }
}
