﻿using System.Collections.Generic;
using MbUnit.Framework;
using System.Linq;

namespace DataDriven.Tests.Rollback
{
    [TestFixture]
    public class LinqCustomerRepositoryTests
    {
        private LinqCustomerRepository m_CustomerRepository = null;

        [SetUp]
        public void Setup()
        {
            m_CustomerRepository = new LinqCustomerRepository();
        }

        [TearDown]
        public void TearDown()
        {
            m_CustomerRepository = null;
        }

        [Test]
        [RollBack2]
        public void GetCustomers_SingleCustomer_PopulatedList()
        {
            Customer c = TestHelper.InsertCustomer();

            List<Customer> customers = m_CustomerRepository.GetCustomers();
            Assert.AreEqual(1, customers.Count);
            Assert.AreEqual(c.CustomerID, customers[0].CustomerID);
        }

        [Test]
        [RollBack2]
        public void GetCustomer_SingleCustomer_PopulatedCustomer()
        {
            Customer c = TestHelper.InsertCustomer();

            Customer customer = m_CustomerRepository.GetCustomer(c.CustomerID);
            Assert.IsNotNull(customer);
            Assert.AreEqual(c.CustomerID, customer.CustomerID);
        }

        [Test]
        [RollBack2]
        public void DeleteOrderDetails()
        {
            NorthwindDataContext db = new NorthwindDataContext();
            db.ExecuteCommand("DELETE FROM [Order Details]");

            var count = (from c in db.Order_Details
                        select c).Count();

            Assert.AreEqual(0, count);
        }
    }
}
