﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using MbUnit.Framework;
using System.Collections;

namespace DataDriven.Tests.TypeFixture
{
    public interface INotNull
    {
        IEnumerable GetNotNullValues();
    }

    public class TypeA : INotNull
    {
        public override string ToString()
        {
            return "TypeA";
        }

        public IEnumerable GetNotNullValues()
        {
            yield return "TypeA";
        }
    }

    public class TypeB : INotNull
    {
        public override string ToString()
        {
            return "TypeB";
        }

        public IEnumerable GetNotNullValues()
        {
            yield return 1;
            yield return 2;
            yield return 3;
            yield return 4;
        }
    }

    public class TypeC : INotNull
    {
        public override string ToString()
        {
            return "TypeC";
        }

        public IEnumerable GetNotNullValues()
        {
            yield return new object();
            yield return null;
            yield return new object();
        }
    }

    [TypeFixture(typeof(INotNull), "Tests the INotNull interface.")]
    public class INotNullTests
    {
        [Provider(typeof(TypeA))]
        public TypeA ProvideTypeA()
        {
            Console.WriteLine("Called ProvideTypeA");
            return new TypeA();
        }

        [Provider(typeof(TypeB))]
        public TypeB ProvideTypeB()
        {
            Console.WriteLine("Called ProvideTypeB");
            return new TypeB();
        }

        [Provider(typeof(TypeC))]
        public TypeC ProvideTypeC()
        {
            Console.WriteLine("Called ProvideTypeC");
            return new TypeC();
        }

        [Test]
        public void TestINotNullValuesNotNull(INotNull instance)
        {
            Console.WriteLine(instance.ToString());

            foreach (object o in instance.GetNotNullValues())
            {
                Assert.IsNotNull(o, "Instance: {0}.  Object was null: {1}", instance, o);
            }
        }
    }
}
