﻿using System.Collections.Generic;
using DataDriven;
using MbUnit.Framework;
using Rhino.Mocks;

namespace BusinessLogic.Tests
{
    [TestFixture]
    public class CustomerControllerTests
    {
        private MockRepository m_Mocks;
        private ICustomerRepository m_CustomerRepos = null;
        private Customer m_MockedCustomer = null;

        private Customer MockCustomer()
        {
            Customer c = new Customer();
            c.ContactName = "John Smith";
            c.CustomerID = "2134";
            return c;
        }

        [SetUp]
        public void Setup()
        {
            m_Mocks = new MockRepository();
            m_CustomerRepos = m_Mocks.CreateMock<ICustomerRepository>();
            CustomerController.CustomerRepository = m_CustomerRepos;

            m_MockedCustomer = MockCustomer();
        }

        [TearDown]
        public void Teardown()
        {
            m_Mocks = null;
        }


        [Test]
        public void GetCustomers_Mocked_ReturnsList()
        {
            using (m_Mocks.Record())
            {
                Expect.Call(m_CustomerRepos.GetCustomers()).Return(new List<Customer> { m_MockedCustomer });
            }

            using (m_Mocks.Playback())
            {
                //First attempt class wasn't static, instantly with unit tests
                List<Customer> customers = CustomerController.GetCustomers();
                Assert.IsNotNull(customers);
                Assert.AreEqual(1, customers.Count);
                Assert.AreEqual(m_MockedCustomer, customers[0]);  //Just does it based on the HashCode
                CustomAssert.AreEqual(m_MockedCustomer, customers[0]); //Gives us more control
            }
        }
        [Test]
        public void GetCustomer_Mocked_ReturnsCustomer()
        {
            using (m_Mocks.Record())
            {
                Expect.Call(m_CustomerRepos.GetCustomer("2134")).Return(m_MockedCustomer);
            }

            using (m_Mocks.Playback())
            {
                Customer customer = CustomerController.GetCustomer("2134");
                Assert.IsNotNull(customer);
                Assert.AreEqual(m_MockedCustomer, customer);
            }
        }
    }
}
